==> ejc-settle-api-3.0.0-20240607.062044-14-sources.jar: com/ejianc/business/settle/bean/SettlementCenterBudgetOtherVO.java <==
package com.ejianc.business.settle.bean;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 建筑工程
 *
 * @author generator
 */
public class SettlementCenterBudgetOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetId; // 预算书主键
    private String detailIndex; // 序号
    private Long parentId; // 父ID
    private String otherCode; // 编码
    private String otherName; // 名称
    private String otherFeature; // 特征
    private String otherUnit; // 单位
    private BigDecimal otherNum; // 承包合同工程量
    private BigDecimal quoteOtherNum; // 对甲结算工程量
    private BigDecimal settlementCenterOtherNum; // 统计工程量
    private BigDecimal otherTaxRate; // 税率
    private BigDecimal otherPrice; // 承包合同综合单价(无税)
    private BigDecimal otherTaxPrice; // 承包合同综合单价(含税)
    private BigDecimal otherMny; // 合价(无税)
    private BigDecimal otherTaxMny; // 合价(含税)
    private BigDecimal otherTax; // 税额
    private BigDecimal quoteOtherMny; // 对甲结算产值(无税)
    private BigDecimal quoteOtherTaxMny; // 对甲结产值(含税)
    private BigDecimal quoteOtherTax; // 结算产值税额
    private BigDecimal settlementCenterOtherMny; // 统计产值(无税)
    private BigDecimal settlementCenterOtherTaxMny; // 统计产值(含税)
    private BigDecimal settlementCenterOtherTax; // 统计产值税额
    private String otherMemo; // 备注
    private Integer leafFlag; // 是否末级
    private Long otherSubjectId; // 成本科目id
    private String otherSubjectName; // 成本科目名称
    private Long dcDrwgrpInfo; // settlement_center_dc_drwgrp_info主键 0 代表 为预算书缓存

    private List<SettlementCenterBudgetOtherVO> children;


    public Long getDcDrwgrpInfo() {
        return dcDrwgrpInfo;
    }

    public void setDcDrwgrpInfo(Long dcDrwgrpInfo) {
        this.dcDrwgrpInfo = dcDrwgrpInfo;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getOtherCode() {
        return otherCode;
    }

    public void setOtherCode(String otherCode) {
        this.otherCode = otherCode;
    }

    public String getOtherName() {
        return otherName;
    }

    public void setOtherName(String otherName) {
        this.otherName = otherName;
    }

    public String getOtherFeature() {
        return otherFeature;
    }

    public void setOtherFeature(String otherFeature) {
        this.otherFeature = otherFeature;
    }

    public String getOtherUnit() {
        return otherUnit;
    }

    public void setOtherUnit(String otherUnit) {
        this.otherUnit = otherUnit;
    }

    public BigDecimal getOtherNum() {
        return otherNum;
    }

    public void setOtherNum(BigDecimal otherNum) {
        this.otherNum = otherNum;
    }

    public BigDecimal getQuoteOtherNum() {
        return quoteOtherNum;
    }

    public void setQuoteOtherNum(BigDecimal quoteOtherNum) {
        this.quoteOtherNum = quoteOtherNum;
    }

    public BigDecimal getSettlementCenterOtherNum() {
        return settlementCenterOtherNum;
    }

    public void setSettlementCenterOtherNum(BigDecimal settlementCenterOtherNum) {
        this.settlementCenterOtherNum = settlementCenterOtherNum;
    }

    public BigDecimal getOtherTaxRate() {
        return otherTaxRate;
    }

    public void setOtherTaxRate(BigDecimal otherTaxRate) {
        this.otherTaxRate = otherTaxRate;
    }

    public BigDecimal getOtherPrice() {
        return otherPrice;
    }

    public void setOtherPrice(BigDecimal otherPrice) {
        this.otherPrice = otherPrice;
    }

    public BigDecimal getOtherTaxPrice() {
        return otherTaxPrice;
    }

    public void setOtherTaxPrice(BigDecimal otherTaxPrice) {
        this.otherTaxPrice = otherTaxPrice;
    }

    public BigDecimal getOtherMny() {
        return otherMny;
    }

    public void setOtherMny(BigDecimal otherMny) {
        this.otherMny = otherMny;
    }

    public BigDecimal getOtherTaxMny() {
        return otherTaxMny;
    }

    public void setOtherTaxMny(BigDecimal otherTaxMny) {
        this.otherTaxMny = otherTaxMny;
    }

    public BigDecimal getOtherTax() {
        return otherTax;
    }

    public void setOtherTax(BigDecimal otherTax) {
        this.otherTax = otherTax;
    }

    public BigDecimal getQuoteOtherMny() {
        return quoteOtherMny;
    }

    public void setQuoteOtherMny(BigDecimal quoteOtherMny) {
        this.quoteOtherMny = quoteOtherMny;
    }

    public BigDecimal getQuoteOtherTaxMny() {
        return quoteOtherTaxMny;
    }

    public void setQuoteOtherTaxMny(BigDecimal quoteOtherTaxMny) {
        this.quoteOtherTaxMny = quoteOtherTaxMny;
    }

    public BigDecimal getQuoteOtherTax() {
        return quoteOtherTax;
    }

    public void setQuoteOtherTax(BigDecimal quoteOtherTax) {
        this.quoteOtherTax = quoteOtherTax;
    }

    public BigDecimal getSettlementCenterOtherMny() {
        return settlementCenterOtherMny;
    }

    public void setSettlementCenterOtherMny(BigDecimal settlementCenterOtherMny) {
        this.settlementCenterOtherMny = settlementCenterOtherMny;
    }

    public BigDecimal getSettlementCenterOtherTaxMny() {
        return settlementCenterOtherTaxMny;
    }

    public void setSettlementCenterOtherTaxMny(BigDecimal settlementCenterOtherTaxMny) {
        this.settlementCenterOtherTaxMny = settlementCenterOtherTaxMny;
    }

    public BigDecimal getSettlementCenterOtherTax() {
        return settlementCenterOtherTax;
    }

    public void setSettlementCenterOtherTax(BigDecimal settlementCenterOtherTax) {
        this.settlementCenterOtherTax = settlementCenterOtherTax;
    }

    public String getOtherMemo() {
        return otherMemo;
    }

    public void setOtherMemo(String otherMemo) {
        this.otherMemo = otherMemo;
    }

    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }

    public Long getOtherSubjectId() {
        return otherSubjectId;
    }

    public void setOtherSubjectId(Long otherSubjectId) {
        this.otherSubjectId = otherSubjectId;
    }

    public String getOtherSubjectName() {
        return otherSubjectName;
    }

    public void setOtherSubjectName(String otherSubjectName) {
        this.otherSubjectName = otherSubjectName;
    }

    public List<SettlementCenterBudgetOtherVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementCenterBudgetOtherVO> children) {
        this.children = children;
    }
}

==> ejc-settle-api-3.0.0-20240617.003144-40-sources.jar: com/ejianc/business/settle/bean/SettlementCenterBudgetOtherVO.java <==
package com.ejianc.business.settle.bean;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 建筑工程
 *
 * @author generator
 */
public class SettlementCenterBudgetOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetId; // 预算书主键
    private String detailIndex; // 序号
    private Long parentId; // 父ID
    private String otherCode; // 编码
    private String otherName; // 名称
    private String otherFeature; // 特征
    private String otherUnit; // 单位
    private BigDecimal otherNum; // 承包合同工程量
    private BigDecimal quoteOtherNum; // 对甲结算工程量
    private BigDecimal settlementCenterOtherNum; // 统计工程量
    private BigDecimal otherTaxRate; // 税率
    private BigDecimal otherPrice; // 承包合同综合单价(无税)
    private BigDecimal otherTaxPrice; // 承包合同综合单价(含税)
    private BigDecimal otherMny; // 合价(无税)
    private BigDecimal otherTaxMny; // 合价(含税)
    private BigDecimal otherTax; // 税额
    private BigDecimal quoteOtherMny; // 对甲结算产值(无税)
    private BigDecimal quoteOtherTaxMny; // 对甲结产值(含税)
    private BigDecimal quoteOtherTax; // 结算产值税额
    private BigDecimal settlementCenterOtherMny; // 统计产值(无税)
    private BigDecimal settlementCenterOtherTaxMny; // 统计产值(含税)
    private BigDecimal settlementCenterOtherTax; // 统计产值税额
    private String otherMemo; // 备注
    private Integer leafFlag; // 是否末级
    private Long otherSubjectId; // 成本科目id
    private String otherSubjectName; // 成本科目名称
    private Long dcDrwgrpInfo; // settlement_center_dc_drwgrp_info主键 0 代表 为预算书缓存
    private String errorMessage;//错误信息集合
    private Integer rowIndex;

    private List<SettlementCenterBudgetOtherVO> children;


    public Long getDcDrwgrpInfo() {
        return dcDrwgrpInfo;
    }

    public void setDcDrwgrpInfo(Long dcDrwgrpInfo) {
        this.dcDrwgrpInfo = dcDrwgrpInfo;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getOtherCode() {
        return otherCode;
    }

    public void setOtherCode(String otherCode) {
        this.otherCode = otherCode;
    }

    public String getOtherName() {
        return otherName;
    }

    public void setOtherName(String otherName) {
        this.otherName = otherName;
    }

    public String getOtherFeature() {
        return otherFeature;
    }

    public void setOtherFeature(String otherFeature) {
        this.otherFeature = otherFeature;
    }

    public String getOtherUnit() {
        return otherUnit;
    }

    public void setOtherUnit(String otherUnit) {
        this.otherUnit = otherUnit;
    }

    public BigDecimal getOtherNum() {
        return otherNum;
    }

    public void setOtherNum(BigDecimal otherNum) {
        this.otherNum = otherNum;
    }

    public BigDecimal getQuoteOtherNum() {
        return quoteOtherNum;
    }

    public void setQuoteOtherNum(BigDecimal quoteOtherNum) {
        this.quoteOtherNum = quoteOtherNum;
    }

    public BigDecimal getSettlementCenterOtherNum() {
        return settlementCenterOtherNum;
    }

    public void setSettlementCenterOtherNum(BigDecimal settlementCenterOtherNum) {
        this.settlementCenterOtherNum = settlementCenterOtherNum;
    }

    public BigDecimal getOtherTaxRate() {
        return otherTaxRate;
    }

    public void setOtherTaxRate(BigDecimal otherTaxRate) {
        this.otherTaxRate = otherTaxRate;
    }

    public BigDecimal getOtherPrice() {
        return otherPrice;
    }

    public void setOtherPrice(BigDecimal otherPrice) {
        this.otherPrice = otherPrice;
    }

    public BigDecimal getOtherTaxPrice() {
        return otherTaxPrice;
    }

    public void setOtherTaxPrice(BigDecimal otherTaxPrice) {
        this.otherTaxPrice = otherTaxPrice;
    }

    public BigDecimal getOtherMny() {
        return otherMny;
    }

    public void setOtherMny(BigDecimal otherMny) {
        this.otherMny = otherMny;
    }

    public BigDecimal getOtherTaxMny() {
        return otherTaxMny;
    }

    public void setOtherTaxMny(BigDecimal otherTaxMny) {
        this.otherTaxMny = otherTaxMny;
    }

    public BigDecimal getOtherTax() {
        return otherTax;
    }

    public void setOtherTax(BigDecimal otherTax) {
        this.otherTax = otherTax;
    }

    public BigDecimal getQuoteOtherMny() {
        return quoteOtherMny;
    }

    public void setQuoteOtherMny(BigDecimal quoteOtherMny) {
        this.quoteOtherMny = quoteOtherMny;
    }

    public BigDecimal getQuoteOtherTaxMny() {
        return quoteOtherTaxMny;
    }

    public void setQuoteOtherTaxMny(BigDecimal quoteOtherTaxMny) {
        this.quoteOtherTaxMny = quoteOtherTaxMny;
    }

    public BigDecimal getQuoteOtherTax() {
        return quoteOtherTax;
    }

    public void setQuoteOtherTax(BigDecimal quoteOtherTax) {
        this.quoteOtherTax = quoteOtherTax;
    }

    public BigDecimal getSettlementCenterOtherMny() {
        return settlementCenterOtherMny;
    }

    public void setSettlementCenterOtherMny(BigDecimal settlementCenterOtherMny) {
        this.settlementCenterOtherMny = settlementCenterOtherMny;
    }

    public BigDecimal getSettlementCenterOtherTaxMny() {
        return settlementCenterOtherTaxMny;
    }

    public void setSettlementCenterOtherTaxMny(BigDecimal settlementCenterOtherTaxMny) {
        this.settlementCenterOtherTaxMny = settlementCenterOtherTaxMny;
    }

    public BigDecimal getSettlementCenterOtherTax() {
        return settlementCenterOtherTax;
    }

    public void setSettlementCenterOtherTax(BigDecimal settlementCenterOtherTax) {
        this.settlementCenterOtherTax = settlementCenterOtherTax;
    }

    public String getOtherMemo() {
        return otherMemo;
    }

    public void setOtherMemo(String otherMemo) {
        this.otherMemo = otherMemo;
    }

    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }

    public Long getOtherSubjectId() {
        return otherSubjectId;
    }

    public void setOtherSubjectId(Long otherSubjectId) {
        this.otherSubjectId = otherSubjectId;
    }

    public String getOtherSubjectName() {
        return otherSubjectName;
    }

    public void setOtherSubjectName(String otherSubjectName) {
        this.otherSubjectName = otherSubjectName;
    }

    public List<SettlementCenterBudgetOtherVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementCenterBudgetOtherVO> children) {
        this.children = children;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public Integer getRowIndex() {
        return rowIndex;
    }

    public void setRowIndex(Integer rowIndex) {
        this.rowIndex = rowIndex;
    }
}
